# script name:	diff_convert.awk
# version, date		: 0.1	2019/09/09
#					: 2.0	2020/06/14 and 2020/09/23 Addition of English string to output 
# function
#	get diff output and generates addition / removal logs
#	出力を受け取り、追加検出、削除検出のログを出力する。
# input			: stdin 
# 入力          : 標準入力
#					output of diff
#					diff 出力
# 	                diff volumelist_old.txt volumelist_new.txt
#						1st. parameter: older list, 2nd. parameter: newer list
# 						第1引数: 古い方のリスト, 第2引数  新しい方のリスト
#	Input is assumed as the following format.
# 	入力の形式は以下を前提としている。
#   Line no. text
#	LINE  1  3a4
#	LINE  2  > A0004700
#	LINE  3  6,7d6
#	LINE  4  < E0281600
#	LINE  5  < E0281700
#	LINE  6  9a9,30
#	LINE  7  > T1301200
#	LINE  8  > T1301300
#     :     
#		Column1 Meaning
#       1桁目   意味
#       >     	Addition detected => generates output
#				追加検出          => 出力する行
#       <       Removal detected  => generate output
#				削除検出          => 出力する行
#       other   ignored
#		それ以外 無視する
# 
# -v option is used to get string of date and time, to add the output
# -v オプションで日付と時刻の文字列を受け取り、stdoutに書く内容に付加する。
#		-v d= date (string) example: 2019/09/29
#			  日付 (文字列) 例 2019/09/29
#		-v t= time (string) example: 17:18
#			  時刻 (文字列) 例 17:18
# 
# Sample usage 
# 実行例 
#     cat difflist.txt | awk -f $AP/diff_convert.awk -v d=$dt_start_separator -v t=$hm_start_separator
#
# output		: stdout
# 出力          : 標準出力
#   Format    CSV format
# 	出力形式  CSV 形式
#	"A0004700","追加検出","2019/09/09","17:18","Addition detected"
#	"E0281600","削除検出","2019/09/09","17:18","Removal detected"
#	"E0281700","削除検出","2019/09/09","17:18","Removal detected"
#   "T1301200","追加検出","2019/09/09","17:18","Addition detected"
#   "T1301300","追加検出","2019/09/09","17:18","Addition detected"
#

BEGIN{
	#	print "Date",d,"Time",t; # for debug/test
}
{ if($1==">")
	{ 
		print "\"" $2 "\",\"追加検出\",\"" d "\",\"" t "\",\"Addition detected\""  	# output Addition info.
																					# 追加情報を出力する
	}
}
{ if($1=="<")
	{ 
		# v.1.1		print "\"" $2 "\",\"削除検出\",\"" d "\",\"" t "\""    			# 削除検出を出力する
		print "\"" $2 "\",\"削除検出\",\"" d "\",\"" t "\",\"Removal detected\""  	# output Removal info.
	}
}
