# script name:	extract_dump_sspvs-i-lstapes-format.awk
# version, date		0.1	2019/08/31
#					0.2	2020/01/09 HPSS 7.5.3.0.0 環境対応。
#							Volume:VVID:SeqNum のVVIDが以前より長いので、固定位置での分離取り出しをやめる。
#                       	UsedやTotalも桁が大きくなってズレが起きているのでブランク区切りで取り出す方法に変更する。
# 					2.0	2020/09/30 English text added to the comments.
#
# function
#   extract information from "dump_sspvs -i 1 --lstapes-format" which is not in the "dump_sspvs -i 1" output
#	dump_sspvs -i 1 --lstapes-format 出力の内、dump_sspvs -i 1 と重複しない情報を取り出す。
# input		: dump_sspvs -i 1 --lstapes-format output
#			: dump_sspvs -i 1 --lstapes-format 出力
#
# output		: stdout
#				  標準出力
#
#  Information is assumed in the following format.
#  入力の形式は以下を前提としている。
#	LINE  1 Volume:VVID:SeqNum           SC   Family       Last Write          Last Read     State    Files     Used    Total
#	LINE  2 A00200:000186a3-04-00000001-01e89b6b4a765ec2-2534:0  1605        0 2018/11/09 05:10:24 2019/01/17 16:50:33 EOM       1408 9516257.0 9607569.4
#	LINE  3 A00201:000186a3-04-00000001-01e89b6b4a784818-2534:0  1605        0 2018/11/08 21:39:17 2019/04/03 10:50:39 EOM       1416 9553287.1 9599331.1
#   LINE  4 A00202:000186a3-04-00000001-01e89b6b4a797116-2534:0  1605        0 2018/11/10 02:19:15 2019/11/08 18:26:32 EOM       1459 9576315.8 9599260.9
#   LINE  5 A00203:000186a3-04-00000001-01e89b6b4a7a9d02-2534:0  1605        0 2018/11/09 11:14:35 2019/01/26 09:46:34 EOM       1428 9532166.0 9602362.3
#   LINE  6 A00204:000186a3-04-00000001-01e89b6b4a7c5d36-2534:0  1605        0 2019/01/11 15:49:19 2019/08/13 19:50:15 EOM       1626 11960889.0 11961558.3
#           A00296:000186a3-04-00000001-01e9149a8872548a-3ec8:0  1605        0 2019/07/27 13:57:00 ---------- -------- EMPTY        0      0.0 10464844.1
#           A00300:000186a3-04-00000001-01e9b52acc7bc0fe-345f:0  1605        0 ---------- -------- ---------- -------- ALLOC        0      0.0 10240000.0
#           A00305:000186a3-04-00000001-01e9b52acc865c30-345f:0  1605        0 2019/11/25 03:13:55 ---------- -------- EOM      10071 10376765.9 10381996.1
#
#         Field positions of collumns are as folllows 
#         ブランク区切りでのフィールド位置は以下。
#           1                         2    3       4    5       6    7        8        9         10      11
#           Volume:VVID:SeqNum        SC   Family  Last Write   Last Read     State    Files     Used    Total
#
#		Volume is extracted and used as the key.
#       Volumeはキーになるフィールドなので取り出す。
#       Used and Total fields are not extracted.
#			Used, Totalは採らない。
#		add "00" to Volume, to make it label text of 8 characters
#		Volumeは6桁なので、"00"を付加する。
#		VVID:SeqNum are extracted using ":" as the separator character.
#
#       Last Write          set "" (null string) when the input is "---------- --------"
#							"---------- --------"のときは""(null)に置き換える
#		Last Read           same as Last Write
#							Last write と同じ
#		State             	Left-aligned
#							左寄せ ALLOC は dump_sspvs -i 1 では出てこない。代わりに"RO"ステータスが表示されている。
#                                ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#       Files             	Right-aligned
# 							右寄せ 桁数は最大何桁か不明。
#
# Output format
# 出力形式  
#		All fields are embraced with quotatoin marks. 
#		全てダブルクオーテーションマークで囲む。
#	"A0020000","EOM","0","1605","9,978,518,689,080","10,074,266,712,950",""
#	"A0020100","EOM","0","1605","10,017,347,555,909","10,065,628,193,851",""
#	"A0020200","EOM","0","1605","10,041,494,906,173","10,065,554,569,672",""
#   "A0020300","EOM","0","1605","9,995,200,481,621","10,068,806,679,717",""
#   "E0002200","EOM","0","1601","3,418,708,209,477","4,449,225,195,469","Read Error"
#   "H1002100","EMPTY","0","2002","0","1,031,457,280","Repack output tape"
#
{ if(NR>1)	# Skip first line which contains a header 
			# ファイル1行目ヘッダー行をスキップする
	{
		x=substr($0,1,6); 			# Volume (Cartridgr ID)
		a=x"00"						#  add "00" -> 8 characters
		
									# VVID
		b=substr($0,8);				#	20200109	get string starting from 8 bytes to the end of line
									#               まず8文字目(Vilumeとコロンで7文字なので)以降を全て取り出す。
		c=b							# 	20200109	
		colon=":"
		offset=index(b,colon)		#	20200109	find offset value (position) of ":"
									#				コロンの位置を探す(1から開始するオフセットが戻る)
		b=substr(b,1,offset-1)		#	20200109	extract string just before ":"
									#				コロンの直前までを取り出す
		
									# SeqNum
		c=substr(c,offset+1)		#	20200109	get string starting just after ":" to the end of line
									#				コロンの直後を取り出す
		space=" "
		offset=index(c,space)		# 	20200109	find offset value (position) of " " (space)
									#				スペースの位置を探す
		c=substr(b,1,offset-1)		#	20200109	extract string just before " "
									#				スペースの直前までを取り出す

		d=$4" "$5					# Last Write 
		{ if(d=="---------- --------")  # set "" (null string) when the input is "---------- --------"
			{
				d=""
			}
		}
		e=$6" "$7					# Last Read
		{ if(e=="---------- --------")	# set "" (null string) when the input is "---------- --------"
			{
				e=""
			}
		}
		f=$8						# State
		g=$9						# Files
		
		print "\""a"\",\""b"\",\""c"\",\""d"\",\""e"\",\""f"\",\""g"\"" ;
	}
}
