# script name:	extract_dump_sspvs-i_detail.awk
# version, date		: 	0.1	2019/08/30
#						0.2	2019/09/30	SCID(Storage Class) field output is not embraced with quotation marks.
#										SCIDフィールドは、ダブルクオーテーションマーク無しで出力される。
# 						2.0	2020/10/01  English text added to the comments.
# function
# 機能
#   extract detail information for each tape volume from "dump_sspvs -i 1"
#	dump_sspvs -i 1 出力の内、テープボリューム毎のdetailを取り出す。

# input
# 入力
#	output of "dump_sspvs -i 1" (detail lines of tape volumes Only)
#	"dump_sspvs -i 1" 出力ファイル(ボリューム毎詳細行のみ)  
#                                ~~~~~~~~~~~~~~~~~~~~~~~
#	Information is assumed in the following format.
#	入力の形式は以下を前提としている。
#           
#                       VV       Storage
#           Volume    Cond Family  Class                 Space Used            Max Volume Size  Other information
#
#	LINE  1 E0266900   EOM      0   1021         16,929,698,489,191         16,929,698,489,233
#	LINE  2 E0267000   EOM      0   1021          9,835,783,712,768          9,835,783,712,768
#	LINE  3 E0267100   EOM      0   1021          1,419,935,093,316          5,026,557,631,100
#	LINE  4 E0267200   EOM      0   1021         12,803,188,312,754         12,803,188,312,788
#	LINE  5 E0267300 EMPTY      0   1021                          0         10,927,689,504,768
#	LINE  6 E0267400   EOM      0   1021            181,011,953,412          9,203,173,046,020
#	LINE  7 H0002600 EMPTY      0   1001                          0            845,710,772,107  Repack output tape
#	LINE  8 H0078900 EMPTY      0   1001                          0            988,971,549,145  Read Error
#
# 	Notes
#		1. Cloumns are separated with spaces. They may be left-, or right-aligned (, or obscure).
#		   各カラムはブランク有り。右寄せ左寄せはさまざま (一部不明のものがある)。
#
# 		Volume				Left-aligned	左寄せ
#		VV Cond				Right-aligned	右寄せ
#		Family   			Right-aligned	右寄せ
# 		Storage Class 		Obscure, but assumed to Right-aligned 不明。右寄せと仮定。
#		Space Used			Right-aligned, integer	右寄せ。整数。
#		Max Volume Size		Right-aligned, integer	右寄せ。整数。
#		Other information 	Left-aligned	左寄せ
#
# output
# 出力
#	 stdout
#
# Output Format is as follows. Each field is embraced with double quotayion marks, excpet for Class(SCID).
# 出力形式  ダブルクオーテーションマークで囲む。但し、Class(SCID)はダブルクオーテーションマークで囲まない。
#
#	"A0020000","EOM","0",1605,"9,978,518,689,080","10,074,266,712,950",""
#	"A0020100","EOM","0",1605,"10,017,347,555,909","10,065,628,193,851",""
#	"A0020200","EOM","0",1605,"10,041,494,906,173","10,065,554,569,672",""
#   "A0020300","EOM","0",1605,"9,995,200,481,621","10,068,806,679,717",""
#   "E0002200","EOM","0",1601,"3,418,708,209,477","4,449,225,195,469","Read Error"
#   "H1002100","EMPTY","0",2002,"0","1,031,457,280","Repack output tape"
#
		{
			a=substr($0,1,8); 			# 8 chars from $0 as 				Volume
										# $0の最初から8文字					Volume

			b=substr($0,9,6); 			# 6 chars starting from 9th of $0 	VV Cond
										# $0の9文字目から6文字     			VV Cond
			hithere=sub(/^ +/,"",b);	#    remove spaces in the left 
										#    左側のスペースを削除する

			c=substr($0,15,7); 			# 7 chars starting from 15th of $0 	Family
										# $0の15文字目から7文字				Family (J-SPACEでは使っていない由)
			hithere=sub(/^ +/,"",c);	#    remove spaces in the left 
										#    左側のスペースを削除する

			d=substr($0,22,7); 			# 7 chars starting from 22th of $0 	Storage Class
										# $0の22文字目から7文字      		Storage Class
			hithere=sub(/^ +/,"",d);	#    remove spaces in the left 
										#    左側のスペースを削除する
			
			e=substr($0,29,27); 		# 27 chars starting from 29th of $0 	Space Used
										# $0の29文字目から27文字     			Space Used
			hithere=sub(/^ +/,"",e);	#    remove spaces in the left 
										#    左側のスペースを削除する
			
			f=substr($0,56,27); 		# 27 chars starting from 56th of $0 	Max Volume Size
										# $0の56文字目から27文字     			Max Volume Size
			hithere=sub(/^ +/,"",f);	#    remove spaces in the left 
										#    左側のスペースを削除する
			
			g=substr($0,85);	 		# chars starting from 85th of $0, to the end of line	Other information
										# $0の85文字目から行末まで								Other information
			
			  print "\""a"\",\""b"\",\""c"\","d",\""e"\",\""f"\",\""g"\"" ;				# print
		}
