# script name:	extract_lshpss-pvr.awk
# version, date		: 0.1	2019/08/25
# 					2.0	2020/10/01 English text added to the comments.
#
# function
#	extract PVR names from "lshpss -pvr" output
#	lshpss -pvr 出力から、pvrの名前を取り出す。
# input			: "lshpss -pvr" output
# 入力			: lshpss -pvr 出力ファイル
# output		: stdout
# 出力			: 標準出力
#
#	Information is assumed in the following format.
#	入力の形式は以下を前提としている。
#	LINE  1:
#	LINE  2:
#	LINE  3:- PVRs -
#	LINE  4:
#	LINE  5:                                           Cartr  Same  Other       Defer
#	LINE  6:                                           Alarm  Job   Job   Dist  Dism.
#	LINE  7:                                     Cartr Thresh On    On    To    Time  Shelf 
#	LINE  8:Name                           Type  Capac (%)    Ctrlr Ctrlr Drive (min) Tape? Devices
#	LINE  9:------------------------------ ----- ----- ------ ----- ----- ----- ----- ----- ---------------
#	LINE 10:SCSI PVR (TS3500 3592)-NEW     SCSI  20000 99     10    5     0     15    Y     T10:IBM|03584L22        0000078A48910401
#	LINE 11:SCSI PVR TS3500                SCSI  3000  90     10    5     0     15    Y     T10:IBM|03584L32        0000078243340403
#	LINE 12:SCSI PVR TS3500(3592)          SCSI  2000  90     10    5     0     15    Y     T10:IBM|03584L22        0000078243340404
#     :        :
#	LINE nn:------------------------------ ----- ----- ------ ----- ----- ----- ----- ----- ---------------
#	LINE nm:Note: A Defer Dismount Time of "N/A" means Deferred Dismount is not enabled for that PVR.
#
#		Name field is left-aligned, 30 character-long, which may contain blanks.
#		Name lines are embedded between 1st. and 2nd. "------------------------------" lines.
#		Name は30桁左寄せ。ブランク有り。
#		Name のリストは"------------------------------"の行に挟まれている。
#
# Output format: Only a PVR Name per line
# 出力形式  PVR 1個の名前だけ/行
#	SCSI PVR (TS3500 3592)-NEW
#	SCSI PVR TS3500
#	SCSI PVR TS3500(3592)
#
#
BEGIN{
	hyphensw=0;		# Initialize occurence number of hyphen lines with 0
					# $1==ハイフン文字列が見つかった回数を記録する。0で初期化しておく。
}
{ if(hyphensw==0)
	{ if( $1=="------------------------------")	# check occurence number of hyphen lines, if this is the first. 
												# 初めてのハイフン文字列なら
		{
			hyphensw=1;
		}
	}
	else
	{ if(hyphensw>=1 && $1=="------------------------------")	# check occurence number of hyphen lines, if this is the second.
																# 2個目(以降)のハイフン文字列なら
		{
			exit												# process terminates
																# 処理終了
		}
		else	# between first and second hyphen string lines => get PVR
				# 1個目のハイフン文字列は見つかった後だが、2個目のハイフン文字列ではない行なら、リスト本体
		{
			a=substr($0,1,30); 			# get 30 characters from the beginning of line   行頭から30文字取り出して
			b=sub(/ +$/,"",a);			# remove trailing blanks                         後ろに付いているブランクを外して
			print a;					# output                                         出力
		}
	}
}
