# script name:	extract_lshpss-sc.awk
# version, date		: 	0.1	2019/08/28
#						0.2	2019/09/30	SCIDフィールドは、ダブルクオーテーションマーク無しで出力
#	 					2.0	2020/10/01 English text added to the comments.
#
# function
#    extract only SC related information from lshpss -sc (first 3 fields, SCID, Name and Media Type)
#    lshpss -sc出力から、sc 情報(最初の3個 SCID, Name and Media Type だけ)を取り出す。。
# input			: output of lshpss -sc (separated into Disk and Tape proir to this awk)
# 入力			  lshpss -sc 出力ファイル(このawkより前に予め Disk, Tapeに切り分けたもの)
#                                        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# output		: stdout
# 出力			: 標準出力
#
#	Information is assumed in the following format.
#	入力の形式は以下を前提としている。
#	LINE  1 
#	LINE  2
#	LINE  3 - DISK STORAGE CLASS LIST  -
#	LINE  4
#	LINE  5                                                                         SSeg           Est                   Media Threshold Mig Prg
#	LINE  6 SC                                         Media                        Size     Avg # PV                Str Block (volumes) Pol Pol
#	LINE  7 ID     Name                                Type                        min/max   SSegs Size   VVBS       Wid Size   Wrn/Crt  ID  ID
#	LINE  8 ------ ----------------------------------- ------------------------- ----- ----- ----- ------ ---------- --- ----- ---- ---- --- ---
#	LINE  9 1      Default (HPSS Logs Archive)         SAN3P Disk                  8MB 64MB  1      20GB  8MB        1   4kB     80 90   5   1  
#	LINE 10 101    SC_D_CHOFU                          SAN3P Disk                  8MB 2GB   4    5460GB  8MB        1   4kB     95 97   1   99999
#	LINE 11 201    SC_D_KAKUDA                         SAN3P Disk                  8MB 2GB   4    5460GB  8MB        1   4kB     95 97   2   99999
#	LINE 12   :
#     :     ------ ----------------------------------- ------------------------- ----- ----- ----- ------ ---------- --- ----- ---- ---- --- ---
#	LINE nn VVBS=Virtual Volume Block Size
#	LINE nm
#       :
#	   Further output follows, but what is needed is SCID, Name and Media Type listed above.
#      この後に cont'd の行が続くが、取り出すのは、最初のパートのSCID, Name and Media Type。
#
# Output format:SCID, Name and Media Type, without trailing blanks in CSV 
#				SCID is not embarced with quotation marks.
# 出力形式     :SCID, Name and Media Type (末尾ブランクなし)、CSV形式
#			    SCIDはダブルクオーテーションマークで囲まない
#
#	1,"Default (HPSS Logs Archive)","SAN3P Disk"
#	601,"SC_D_STD","SAN3P Disk"
#	9003,"SC_T_901_1","3592 E08 Standard Tape"
#   9004,"SC_T_901_2","3592 E08 Standard Tape"
#
BEGIN{
	hyphensw=0;		# Initialize occurence number of hyphen lines with 0
					# $1==ハイフン文字列が見つかった回数を記録する。0で初期化しておく。
}
{ if(hyphensw==0)
	{ if( $1=="------")							# check occurence number of hyphen lines, if this is the first. 
												# 初めてのハイフン文字列なら
		{
			hyphensw=1;
		}
	}
	else
	{ if(hyphensw>=1 && $1=="------")			# check occurence number of hyphen lines, if this is the second.
												# 2個目(以降)のハイフン文字列なら
		{
			exit								# process terminates
												# 処理終了
		}
		else	# between first and second hyphen string lines => get PVR
				# 1個目のハイフン文字列は見つかった後だが、2個目のハイフン文字列ではない行なら、リスト本体
		{
			a=substr($0,1,6); 			# SCID   6 characters at the beginning of the line  $0の最初から6文字
			hithere=sub(/ +$/,"",a);	#        remove trailing spaces                     右側のスペースを削除する
			b=substr($0,8,35); 			# SCName 35 characters beginning at offset 8        $0の8文字目から35文字 
			hithere=sub(/ +$/,"",b);	#        remove trailing spaces                     右側のスペースを削除する
			c=substr($0,44,25); 		# Media Type 25 characters beginning at offset 44   $0の44文字目から25文字
			hithere=sub(/ +$/,"",c);	#        remove trailing spaces                     右側のスペースを削除する
			
			print a",\""b"\",\""c"\"" ;							# output                    出力
		}
	}
}
