# script name:	proc_dumppv_pvl.awk 
# version, date		0.1	2019/08/23
# 					0.2	2019/08/27
#					0.3	2019/09/30	SCIDフィールドは、ダブルクオーテーションマーク無しで出力
#					0.4	2020/01/09	HPSS 7.5.3.0.0 環境対応。
#									Type欄に従来よりも長い情報が現れるので、これに対応して取り出し方法を変更。
# 					2.0	2020/09/30 English text added to the comments.
#
# function
#   generate CSV from the output of "dumppv_pvl"
#	dumppv_pvl のリストから、CSVファイルを作成する。
# input			: 	dumppv_pvl output
#					dumppv_pvl 出力
# output		: 	stdout
#					標準出力
#	Information is assumed in the following format.
#	入力の形式は以下を前提としている。
#	LINE 1:
#	LINE 2:
#	LINE 3:PVL Physical Volumes:
#	LINE 4:
#	LINE 5:	Name			Type		Class		State           <=== Skip first 5 lines			最初の5行は読み飛ばし
#	LINE 6:	A0000000        3592 E08 XL Tape	unallocated	Idle    <=== process starts at line 6 	6行目から処理
#	LINE 7:	A0000100        3592 E08 XL Tape	unallocated	Idle
#	:
#	LINE m:	D0910100              SAN3P Disk	601       	Busy
#	LINE n:	E0449900        3592 E07 XL Tape	unallocated	Idle 
#	:      	GENERI00      Unknown media type	unallocated	Idle
#	:		H0000000          3580 Gen4 Tape	1001       	Idle
#          	S0036900    3592 E08 Standard Tape	    1001		Idle  <=== Long device type 
#			S0037000        3592 E07 XL Tape	unallocated		Idle

#	:
# Output format
# 出力形式
#	"A0000000",unallocated,"Idle","3592 E08 XL Tape"
#	"A0000100",unallocated,"Idle","3592 E08 XL Tape"
#	"A0000300",unallocated,"Idle","3592 E08 XL Tape"
#	"D0910100",601,"Busy","SAN3P Disk"
#	"D0910200",601,"Busy","SAN3P Disk"
#	"GENERI00",unallocated,"Idle","Unknown media type"
#
#		20190930	Strings are embraced with quotation marks except Class(SCID).
#		20190930	Class(SCID) is not embraced with quotation marks, it may be treated as number or string in Excel, depending on its value.
#
{ if(NR>5)								# Skip first 5 lines
										# ファイル冒頭のブランク行やヘッダー行をスキップする(5行目まではスキップ) 2019/08/27
	{
		a=substr($0,10);b=sub(/^ +/,"",a);	# 20200109 get string starting at 10th. character to the end of line, and remove proceeding blanks
											#          sub modifies a sttring value in the position of 3rd. parameter
											#          10文字目以降を全て取り出して先頭のブランクを外す。
											#          sub は、第3パラメーターの変数の文字列を更新する
		t="\t"
		c=index(a,t)			# 20200109 find the tab-character and get its offset from 1
								#          タブ記号の位置を探す(1から開始するオフセットが戻る)
		d=substr(a,1,c-1)		# 20200109 extract string offset 1 to just before the tab-character
								#          先頭からタブ位置の直前までを取り出す
		print "\"" $1 "\",\"" $(NF-1) "\",\""$(NF-0) "\",\"" d "\""	# format output 
																	# フィールド順を入れ替えて書き出す。
	}
}
