# script name:	proc_dumppv_pvr.awk 
# version, date		: 	0.1	2019/08/23
#						0.2 2020/01/11 Mount Statusの取り出し方を変更
# 						2.0	2020/09/30 English text added to the comments.
#
# function
#   process list of dumppv_pvr command and make a CSV
#	dumppv_pvr のリストから、CSVファイルを作成する。
# input			: 	lines of dumppv_pvr command (except "Physical Volumes Pending Move" section )
#					dumppv_pvr 出力ファイル     ("Physical Volumes Pending Move" 部を除く)
# output		: stdout
#				  標準出力
#	Information is assumed in the following format.
# 入力の形式は以下を前提としている。
#	LINE 1:													<= blank, skip				1行目は空白→読み飛ばし
#	LINE 2:													<= blank, skip				2行目は空白→読み飛ばし
#	LINE 3:PVR 'SCSI PVR TS3500(3592)' Physical Volumes: 	<= PVR name is listed here	PVR名がこの書き方で入る
#	LINE 4:													<= blank, skip				4行目は空白→読み飛ばし
#	LINE 5: Name	Total Mounts	Mount Status			<= header line, skip		5行目はヘッダー→読み飛ばし
#	LINE 6: T10001	    124		DISMOUNTED 					<= data begins here			6行目以降がデータ
#	LINE 7: T10009	     71		DISMOUNTED
#	:
#	LINE mm: H00106	      1		MOUNTED
#	LINE nn: T13040	     37		CHECKED OUT					<= Mount Status may contain more than 1 word          2、3単語のこともある
#	:
#															<== blank lines follow after the data lines,skip  データの後に空行→読み飛ばし
# Output format
# 出力形式
#	"T1000100","SCSI PVR TS3500(3592)",124,"DISMOUNTED"
#		Volume is located at the beginning of the line and add "00" to make it label text of 8 characters
#		Volume は、最初のカラムにする。Volume は6文字で出てくるので"00"を追加して8文字にする。
#		set PVR Name area, taken from the list heading (line 3)
#		PVR Name名は、ヘッダー(3行目)から取り出す。
#		String fields are embraced with quotatoin marks. "Total Mounts" is an integer field, and not embraced in the output.
#		文字列フィールドはクオーテーションで囲んでおく。マウント回数は数字なので、クオーテーションで囲まない。
#
{	if(NR==3)								# if the record is the 3rd. line
	{
		pvrname=$0;										# get the contents of the whole line
														# 一旦行全体をpvrnameに入れてから
		b=sub(/^PVR '/,"",pvrname);						# remove string before PVR name
														# PVR名の前の文字列を取り去る
		b=sub(/' Physical Volumes:$/,"",pvrname);		# remove string after PVR name
														# PVR名の後の文字列を取り去る
	}
}
{	if(NR>=6 && NF>=3)		# process only records which are beginning from line 6, and hold equal to or more than 3 fields
							# 6行目以降、かつ、3フィールド以上ある行だけを処理
							
	{
		cartid   =$1;
			volid=cartid"00";		# add trailing "00" to cartridge ID
									# 出力は6桁のカートリッジIDなので"00"を付加。
		nummounts=$2;				# Total Mounts 
									# Mount Status 
		statmounts="";for(i=3;i<=NF;i++) statmounts=statmounts $i" "; 	# concatenate fields 3 to the end of line
																		# 3番目以降のフィールドを行末まで連結
		b=sub(/ $/,"",statmounts);										# remove trailing " " at the end of string
																		# 上の行の処理では最後に" "が付くので、取り外す 
		#
		print "\"" volid "\",\"" pvrname "\"," nummounts ",\"" statmounts "\""	# output 
																				# まとめて出力
	}
}
