# script name:	proc_dumppv_pvr_pendingMove.awk
# version, date		: 	0.1	2020/01/11
# 						2.0	2020/09/30 English text added to the comments.
# function
#	process list in "Physical Volumes Pending Move" section of dumppv_pvr command
#	dumppv_pvr のリストのうち、"Physical Volumes Pending Move"のデータを処理してCSVファイルを作成する。
# input			: lines starting with "Physical Volumes Pending Move" line of dumppv_pvr command
#				  dumppv_pvr 出力ファイルの"Physical Volumes Pending Move"行以下の部分
# output		: stdout
#				  標準出力
#	Information is assumed in the following format.
# 入力の形式は以下を前提としている。
#	LINE 1:	    Physical Volumes Pending Move (not assigned to a PVR); Move Retry Required:  <= Title line,skip 1行目は題名→読み飛ばし
#	LINE 2:													<= blank line,skip	2行目は空白→読み飛ばし
#	LINE 3:	Name	 Total Mounts	Mount Status			<= header line,skip	3行目はヘッダー→読み飛ばし
#	LNIE 4:	E00998	     33		MOVE PENDING				<= data begins at line 4	4行目以降がデータ
#	LNIE 5:	T01841	      3		MOVE PENDING				<= Mount Status may contain more than 1 word          2、3単語のこともあるので
#	       	T11933	    204		MOVE PENDING                <= Mount Status are extracted using columns 3 to end  3番目以降取り出しとする
#		      :
#          	T12303	     43		MOVE SHELF PENDING
#			T12304	     55		MOVE SHELF PENDING
#															<== blank lines follow after the data lines,skip  データの後に空行→読み飛ばし
# Output format
# 出力形式
#	"E0099800","PVR unassigned",33,"MOVE PENDING"
#		Volume is located at the beginning of the line and add "00" to make it label text of 8 characters
#		Volume は、最初のカラムにする。Volume は6文字で出てくるので"00"を追加して8文字にする。
#		set "PVR unassigned" fixed string for PVR Name area  (String could be changed in this awk script)
#		PVR Name名は、"PVR unassigned"と固定値をセットする。(値はこのスクリプト内で変更可能)
#		String fields are embraced with quotatoin marks. "Total Mounts" is an integer field, and not embraced in the output.
#		文字列フィールドはクオーテーションで囲んでおく。マウント回数は数字なので、クオーテーションで囲まない。
#
BEGIN{
	pvrname="PVR unassigned"								# fixed string for PVR Name area
															# PVR名フィールド 固定文字列
}
#
{	if(NR>=4 && NF>=3)		# process only records which are beginning from line 4, and hold equal to or more than 3 fields
							# 4行目以降、かつ、3フィールド以上ある行だけを処理
	{
		cartid   =$1;
			volid=cartid"00";	# add trailing "00" to cartridge ID
								# 出力は6桁のカートリッジIDなので"00"を付加。
		nummounts=$2;			# Total Mounts 
		# 						# Mount Status 
		statmounts="";for(i=3;i<=NF;i++) statmounts=statmounts $i" "; 	# concatenate fields 3 to the end of line
																		# 3番目以降のフィールドを行末まで連結
		b=sub(/ $/,"",statmounts);										# remove trailing " " at the end of string
																		# 上の行の処理では最後に" "が付くので、取り外す 
		#
		print "\"" volid "\",\"" pvrname "\"," nummounts ",\"" statmounts "\""	# output 
																				# まとめて出力
	}
}
